@@ -23,7 +23,7 @@ from conda.cli.common import specs_from_url, confirm_yn, check_non_admin, ensure
 from conda.core.subdir_data import SubdirData
 from conda.core.link import UnlinkLinkTransaction, PrefixSetup
 from conda.cli.install import check_prefix, clone, print_activate
-from conda.base.constants import ChannelPriority, ROOT_ENV_NAME, UpdateModifier
+from conda.base.constants import ChannelPriority, ROOT_ENV_NAME, UpdateModifier, DepsModifier
 from conda.core.solve import diff_for_unlink_link_precs
 from conda.core.envs_manager import unregister_env
 from conda.core.package_cache_data import PackageCacheData
@@ -49,15 +49,15 @@ import json
 import tempfile
 import logging
 
+import mamba
 import mamba.mamba_api as api
 
-from mamba.post_solve_handling import post_solve_handling
 from mamba.utils import get_index, to_package_record_from_subjson, init_api_context
 
 log = getLogger(__name__)
 stderrlog = getLogger('mamba.stderr')
 
-banner = """
+banner = f"""
                   __    __    __    __
                  /  \\  /  \\  /  \\  /  \\
                 /    \\/    \\/    \\/    \\
@@ -73,7 +73,7 @@ banner = """
         ██║ ╚═╝ ██║██║  ██║██║ ╚═╝ ██║██████╔╝██║  ██║
         ╚═╝     ╚═╝╚═╝  ╚═╝╚═╝     ╚═╝╚═════╝ ╚═╝  ╚═╝
 
-        Supported by @QuantStack
+        mamba ({mamba.__version__}) supported by @QuantStack
 
         GitHub:  https://github.com/QuantStack/mamba
         Twitter: https://twitter.com/QuantStack
@@ -155,7 +155,6 @@ def to_txn(specs_to_add, specs_to_remove, prefix, to_link, to_unlink, index=None
         final_precs.add(rec)
         to_link_records.append(rec)
 
-    final_precs, specs_to_add, specs_to_remove = post_solve_handling(context, prefix_data, final_precs, specs_to_add, specs_to_remove)
     unlink_precs, link_precs = diff_for_unlink_link_precs(prefix,
                                                           final_precs=IndexedSet(PrefixGraph(final_precs).graph),
                                                           specs_to_add=specs_to_add,
@@ -187,7 +186,8 @@ def handle_txn(unlink_link_transaction, prefix, args, newenv, remove_op=False):
 
     if context.dry_run:
         actions = unlink_link_transaction._make_legacy_action_groups()[0]
-        cli_common.stdout_json_success(prefix=prefix, actions=actions, dry_run=True)
+        if context.json:
+            cli_common.stdout_json_success(prefix=prefix, actions=actions, dry_run=True)
         raise DryRunExit()
 
     try:
@@ -300,10 +300,17 @@ def remove(args, parser):
 
         package_cache = api.MultiPackageCache(context.pkgs_dirs)
         transaction = api.Transaction(solver, package_cache)
-        to_link, to_unlink = transaction.to_conda()
+        downloaded = transaction.prompt(PackageCacheData.first_writable().pkgs_dir, repos)
+        if not downloaded:
+            exit(0)
+
+        mmb_specs, to_link, to_unlink = transaction.to_conda()
         transaction.log_json()
 
-        conda_transaction = to_txn((), specs, prefix, to_link, to_unlink)
+        specs_to_add = [MatchSpec(m) for m in mmb_specs[0]]
+        specs_to_remove = [MatchSpec(m) for m in mmb_specs[1]]
+
+        conda_transaction = to_txn(specs_to_add, specs_to_remove, prefix, to_link, to_unlink)
         handle_txn(conda_transaction, prefix, args, False, True)
 
 def install(args, parser, command='install'):
@@ -313,7 +320,7 @@ def install(args, parser, command='install'):
     context.validate_configuration()
     check_non_admin()
 
-    init_api_context()
+    init_api_context(use_mamba_experimental)
 
     newenv = bool(command == 'create')
     isinstall = bool(command == 'install')
@@ -427,9 +434,10 @@ def install(args, parser, command='install'):
     specs = []
 
     if args.file:
+        file_specs = []
         for fpath in args.file:
             try:
-                file_specs = specs_from_url(fpath, json=context.json)
+                file_specs += specs_from_url(fpath, json=context.json)
             except Unicode:
                 raise CondaValueError("Error reading file, file should be a text file containing"
                                  " packages \nconda create --help for details")
@@ -513,6 +521,10 @@ def install(args, parser, command='install'):
 
     solver = api.Solver(pool, solver_options)
     solver.add_jobs(mamba_solve_specs, solver_task)
+    solver.set_postsolve_flags(
+        [(api.MAMBA_NO_DEPS, context.deps_modifier == DepsModifier.NO_DEPS), 
+         (api.MAMBA_ONLY_DEPS, context.deps_modifier == DepsModifier.ONLY_DEPS)]
+    )
     success = solver.solve()
     if not success:
         print(solver.problems_to_str())
@@ -521,7 +533,11 @@ def install(args, parser, command='install'):
 
     package_cache = api.MultiPackageCache(context.pkgs_dirs)
     transaction = api.Transaction(solver, package_cache)
-    to_link, to_unlink = transaction.to_conda()
+    mmb_specs, to_link, to_unlink = transaction.to_conda()
+
+    specs_to_add = [MatchSpec(m) for m in mmb_specs[0]]
+    specs_to_remove = [MatchSpec(m) for m in mmb_specs[1]]
+
     transaction.log_json()
 
     downloaded = transaction.prompt(PackageCacheData.first_writable().pkgs_dir, repos)
@@ -530,14 +546,14 @@ def install(args, parser, command='install'):
     PackageCacheData.first_writable().reload()
 
     if python_added:
-        specs = [s for s in specs if s.name != 'python']
+        specs_to_add = [s for s in specs_to_add if s.name != 'python']
 
     if use_mamba_experimental and not os.name == 'nt':
-        if command == 'create' and not isdir(context.target_prefix):
+        if command == 'create' and not isdir(context.target_prefix) and not context.dry_run:
             mkdir_p(prefix)
         transaction.execute(prefix_data, PackageCacheData.first_writable().pkgs_dir)
     else:
-        conda_transaction = to_txn(specs, (), prefix, to_link, to_unlink, index)
+        conda_transaction = to_txn(specs_to_add, specs_to_remove, prefix, to_link, to_unlink, index)
         handle_txn(conda_transaction, prefix, args, newenv)
 
     try:
@@ -757,6 +773,10 @@ def main(*args, **kwargs):
     if not args:
         args = sys.argv
 
+    if "--version" in args:
+        from mamba._version import __version__
+        print("mamba {}".format(__version__))
+
     args = tuple(ensure_text_type(s) for s in args)
 
     if len(args) > 2 and args[1] == 'env' and args[2] == 'create':
